@@ -60,9 +60,6 @@ func TestAdd(t *testing.T) {
 }
 
 func TestFilter(t *testing.T) {
-	zig := map[string]any{
-		ExtraBuilder: "zig",
-	}
 	data := []*Artifact{
 		{
 			Name:   "foo",
@@ -77,7 +74,6 @@ func TestFilter(t *testing.T) {
 		{
 			Name:   "bar",
 			Goarch: "amd64",
-			Extra:  zig,
 		},
 		{
 			Name:    "bar",
@@ -102,7 +98,6 @@ func TestFilter(t *testing.T) {
 		{
 			Name:   "foobar",
 			Goarch: "arm",
-			Extra:  zig,
 		},
 		{
 			Name: "check",
@@ -145,7 +140,7 @@ func TestFilter(t *testing.T) {
 	require.Len(t, artifacts.Filter(ByGoamd64("v3")).items, 1)
 	require.Len(t, artifacts.Filter(ByGoamd64("v4")).items, 1)
 
-	require.Len(t, artifacts.Filter(And(ByGoarch("arm"), ByGoarm("6"))).items, 2)
+	require.Len(t, artifacts.Filter(And(ByGoarch("arm"), ByGoarm("6"))).items, 3)
 	require.Empty(t, artifacts.Filter(ByGoarm("7")).items)
 
 	require.Len(t, artifacts.Filter(ByType(Checksum)).items, 2)
